@@ -1,7 +1,5 @@
 /*
 
-  $Id$
-
   G N O K I I
 
   A Linux/Unix toolset and driver for the mobile phones.
@@ -26,7 +24,7 @@
   Copyright (C) 1999-2000 Hugh Blemings & Pavel Janik ml.
   Copyright (C) 2000      Jan Derfinak
   Copyright (C) 2001      Jan Kratochvil
-  Copyright (C) 2001-2009 Pawel Kot
+  Copyright (C) 2001-2011 Pawel Kot
   Copyright (C) 2002-2004 BORBELY Zoltan
   Copyright (C) 2005      Bastien Nocera
 
@@ -729,7 +727,7 @@ static gn_error cfg_psection_load(gn_config *cfg, const char *section, const gn_
 		return GN_ERR_NOPHONE;
 	}
 
-	/* You need to specify at least model and port in the phone section */
+	/* You need to specify at least model, port and connection in the phone section */
 	if (!(val = gn_cfg_get(gn_cfg_info, section, "model"))) {
 		fprintf(stderr, _("You need to define '%s' in the config file.\n"), "model");
 		return GN_ERR_NOMODEL;
@@ -865,6 +863,89 @@ static gn_error cfg_psection_load(gn_config *cfg, const char *section, const gn_
 	return GN_ERR_NONE;
 }
 
+#define SETFLAG(f) \
+if (!gnokii_strcmpsep(#f, val, ',')) {\
+	phone_model.flags |= PM_##f;\
+	dprintf("Flag PM_%s\n", #f);\
+	continue;\
+}
+/* Load phone flags (formerly a static array in misc.c) */
+gn_phone_model *gn_cfg_get_phone_model(struct gn_cfg_header *cfg, const char *product_name)
+{
+	struct gn_cfg_header *hdr;
+	char *val, *comma, *end, *section = "flags";
+	int count;
+	static gn_phone_model phone_model = {NULL, NULL, 0};
+	static char model[GN_MODEL_MAX_LENGTH] = "";
+
+	if (phone_model.model)
+		return &phone_model;
+
+	val = gn_cfg_get(gn_cfg_info, section, product_name);
+	if (val) {
+		phone_model.model = model;
+		/* Ignore trailing whitespace (leading whitespace has been stripped when loading the config file) */
+		comma = val;
+		while (*comma && *comma != ',')
+			comma++;
+		end = comma;
+		while (end > val && (isblank(*end) || *end == ','))
+			end--;
+		count = end - val + 1;
+		snprintf(model, GN_MODEL_MAX_LENGTH, "%.*s", count, val);
+
+		/* Check flags */
+		val = comma;
+		for (;;) {
+			while (*val && *val != ',')
+				val++;
+			/* This skips also empty fields */
+			while (*val && (*val == ',' || isblank(*val)))
+				val++;
+			if (!*val)
+				break;
+			SETFLAG(OLD_DEFAULT);
+			SETFLAG(DEFAULT);
+			SETFLAG(DEFAULT_S40_3RD);
+			SETFLAG(CALLERGROUP);
+			SETFLAG(NETMONITOR);
+			SETFLAG(KEYBOARD);
+			SETFLAG(SMS);
+			SETFLAG(CALENDAR);
+			SETFLAG(DTMF);
+			SETFLAG(DATA);
+			SETFLAG(SPEEDDIAL);
+			SETFLAG(EXTPBK);
+			SETFLAG(AUTHENTICATION);
+			SETFLAG(FOLDERS);
+			SETFLAG(FULLPBK);
+			SETFLAG(SMSFILE);
+			SETFLAG(EXTPBK2);
+			SETFLAG(EXTCALENDAR);
+			SETFLAG(XGNOKIIBREAKAGE);
+			/* FIXME? duplicated code from above */
+			comma = val;
+			while (*comma && *comma != ',')
+				comma++;
+			end = comma;
+			while (end > val && (isblank(*end) || *end == ','))
+				end--;
+			count = end - val + 1;
+			dprintf("Unknown flag \"%.*s\"\n", count, val);
+		}
+		return &phone_model;
+	}
+#undef SETFLAG
+
+	/* Give the user some hint on why the product_name wasn't found */
+	hdr = cfg_header_get(cfg, (char *)section);
+	if (!hdr) {
+		fprintf(stderr, _("No %s section in the config file.\n"), section);
+	}
+
+	return &phone_model;
+}
+
 static bool cfg_get_log_target(gn_log_target *t, const char *opt)
 {
 	char *val;
@@ -907,6 +988,7 @@ static char **get_locations(int *retval)
 	char *appdata, *homedrive, *homepath, *systemroot; /* env variables */
 	int size = 3; /* default size for config_file_locations */
 	char path[MAX_PATH_LEN];
+	const char *fname = "gnokii.ini";
 
 	*retval = size;
 
@@ -917,14 +999,14 @@ static char **get_locations(int *retval)
 	homepath = getenv("HOMEPATH");
 	systemroot = getenv("SYSTEMROOT");
 	/* 1. %APPDATA%\gnokii\config */
-	snprintf(path, MAX_PATH_LEN, "%s\\gnokii\\config", appdata);
+	snprintf(path, MAX_PATH_LEN, "%s\\gnokii\\%s", appdata, fname);
 	config_file_locations[0] = strdup(path);
 	/* old gnokii behaviour */
 	/* 2. %HOMEDRIVE%\%HOMEPATH%\_gnokiirc */
-	snprintf(path, MAX_PATH_LEN, "%s\\%s\\_gnokiirc", homedrive, homepath);
+	snprintf(path, MAX_PATH_LEN, "%s\\%s\\%s", homedrive, homepath, fname);
 	config_file_locations[1] = strdup(path);
 	/* 3. %SYSTEMROOT%\gnokiirc */
-	snprintf(path, MAX_PATH_LEN, "%s\\gnokiirc", systemroot);
+	snprintf(path, MAX_PATH_LEN, "%s\\%s", systemroot, fname);
 	config_file_locations[2] = strdup(path);
 
 	return config_file_locations;
@@ -1145,6 +1227,9 @@ GNOKII_API gn_error gn_cfg_phone_load(const char *iname, struct gn_statemachine
 	char section[256];
 	gn_error error;
 
+	if (!state)
+		return GN_ERR_INTERNALERROR;
+
 	if (iname == NULL || *iname == '\0') {
 		state->config = gn_config_global;
 	} else {
