@@ -1,6 +1,6 @@
 /*
 
-  $Id: gsm-api.c,v 1.69 2006/06/11 16:39:48 deller Exp $
+  $Id$
 
   G N O K I I
 
@@ -22,7 +22,7 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999-2000 Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 1999-2000 Hugh Blemings & Pavel Janik ml.
   Copyright (C) 2001      Chris Kemp, Manfred Jonsson
   Copyright (C) 2001-2002 Pavel Machek
   Copyright (C) 2001-2003 Pawel Kot
@@ -41,11 +41,12 @@
 
 */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 
-#include "config.h"
 #include "compat.h"
 #include "misc.h"
 #include "gnokii.h"
@@ -105,6 +106,8 @@ static gn_error register_driver(gn_driver *driver, const char *model, char *setu
 
 	if (setupmodel) {
 		data = calloc(1, sizeof(gn_data));
+		if (!data)
+			return GN_ERR_INTERNALERROR;
 		data->model = setupmodel;
 		p_data = data;
 	} else {
@@ -113,7 +116,8 @@ static gn_error register_driver(gn_driver *driver, const char *model, char *setu
 	if (strstr(driver->phone.models, model) != NULL)
 		error = driver->functions(GN_OP_Init, p_data, sm);
 
-	if (data) free(data);
+	if (data)
+		free(data);
 	return error;
 }
 
@@ -128,19 +132,25 @@ GNOKII_API gn_error gn_gsm_initialise(struct gn_statemachine *sm)
 	gn_error ret;
 
 	dprintf("phone instance config:\n");
-	dprintf("model: %s\n", sm->config.model);
-	dprintf("port_device: %s\n", sm->config.port_device);
-	dprintf("connection_type: %d\n", sm->config.connection_type);
-	dprintf("init_length: %d\n", sm->config.init_length);
-	dprintf("serial_baudrate: %d\n", sm->config.serial_baudrate);
-	dprintf("serial_write_usleep: %d\n", sm->config.serial_write_usleep);
-	dprintf("hardware_handshake: %d\n", sm->config.hardware_handshake);
-	dprintf("require_dcd: %d\n", sm->config.require_dcd);
-	dprintf("smsc_timeout: %d\n", sm->config.smsc_timeout);
-	dprintf("connect_script: %s\n", sm->config.connect_script);
-	dprintf("disconnect_script: %s\n", sm->config.disconnect_script);
-	dprintf("rfcomm_cn: %d\n", (int)sm->config.rfcomm_cn);
-	dprintf("sm_retry: %s\n", sm->config.sm_retry ? "on" : "off");
+	dprintf("model = %s\n", sm->config.model);
+	dprintf("port = %s\n", sm->config.port_device);
+	dprintf("connection = %s\n", gn_lib_get_connection_name(sm->config.connection_type));
+	if (sm->config.init_length) {
+		dprintf("initlength = %d\n", sm->config.init_length);
+	} else {
+		dprintf("initlength = default\n");
+	}
+	dprintf("serial_baudrate = %d\n", sm->config.serial_baudrate);
+	dprintf("serial_write_usleep = %d\n", sm->config.serial_write_usleep);
+	dprintf("handshake = %s\n", sm->config.hardware_handshake ? "hardware" : "software");
+	dprintf("require_dcd = %d\n", sm->config.require_dcd);
+	dprintf("smsc_timeout = %d\n", sm->config.smsc_timeout / 10);
+	if (*sm->config.connect_script)
+		dprintf("connect_script = %s\n", sm->config.connect_script);
+	if (*sm->config.disconnect_script)
+		dprintf("disconnect_script = %s\n", sm->config.disconnect_script);
+	dprintf("rfcomm_channel = %d\n", (int)sm->config.rfcomm_cn);
+	dprintf("sm_retry = %d\n", sm->config.sm_retry);
 
 	if (sm->config.model[0] == '\0') return GN_ERR_UNKNOWNMODEL;
 	if (sm->config.port_device[0] == '\0') return GN_ERR_FAILED;
@@ -158,6 +168,9 @@ GNOKII_API gn_error gn_gsm_initialise(struct gn_statemachine *sm)
 	REGISTER_DRIVER(at, sm->config.model);
 	REGISTER_DRIVER(nokia_6160, NULL);
 	REGISTER_DRIVER(gnapplet, NULL);
+#ifdef HAVE_PCSC
+	REGISTER_DRIVER(pcsc, sm->config.model);
+#endif
 
 	return GN_ERR_UNKNOWNMODEL;
 }
