@@ -234,14 +234,7 @@ static const char *get_langinfo_codeset(void)
 #ifdef HAVE_LANGINFO_CODESET
 		codeset = nl_langinfo(CODESET);
 #else
-#  ifdef WIN32
-		/* As suggested by Ben Bryant, http://codesnipers.com/?q=node/46 */
-		char szCP[10];
-		snprintf(szCP, sizeof(szCP), ".%d", GetACP());
-		codeset = setlocale(LC_ALL, szCP);
-#  else
 		codeset = locale_charset();
-#  endif
 #endif
 	}
 	return codeset;
@@ -290,6 +283,10 @@ int char_mblen(const char *src)
 	return len;
 }
 
+#ifndef ICONV_CONST
+#  define ICONV_CONST const
+#endif
+
 /**
  * char_mbtowc:
  * @wchar_t: buffer for the converted wide char string
@@ -402,7 +399,7 @@ fallback:
  * only 10, and probably they will never change, so hardcoding them
  * here is rather safe.
  */
-static bool char_def_alphabet_ext(unsigned int value)
+bool char_def_alphabet_ext(unsigned int value)
 {
 	return (value == 0x0c ||
 		value == '^' ||
@@ -416,6 +413,22 @@ static bool char_def_alphabet_ext(unsigned int value)
 		value == 0x20ac);
 }
 
+/**
+ * char_def_alphabet_ext_count:
+ * @input: input string
+ * @lengh: input string length
+ *
+ * Returns: number of extended GSM alphabet characters in the input string
+ */
+int char_def_alphabet_ext_count(unsigned char *input, int length)
+{
+	int i, retval = 0;
+	for (i = 0; i < length; i++)
+		if (char_def_alphabet_ext(input[i]))
+			retval++;
+	return retval;
+}
+
 /**
  * char_def_alphabet_ext_decode:
  * @value: the character to decode
@@ -621,7 +634,7 @@ int char_7bit_pack(unsigned int offset, unsigned char *input,
 	char *ucs2str;
 
 	/* FIXME: do it outside this function */
-	/* FIXME: scheduled for 0.6.29 */
+	/* FIXME: scheduled for 0.6.31 */
 	/* First, let's know the encoding. We convert it from something to UCS-2 */
 	ucs2str = calloc(2 * len, sizeof(unsigned char));
 	if (!ucs2str)
@@ -645,7 +658,6 @@ int char_7bit_pack(unsigned int offset, unsigned char *input,
 		unsigned int a = 0xff & ucs2str[2 * i], b = 0xff & ucs2str[2 * i + 1];
 
 		in_num = 256 * a + b;
-
 		if (char_def_alphabet_ext(in_num)) {
 			byte = GN_CHAR_UNI_ESCAPE;
 			double_char = true;
@@ -785,7 +797,7 @@ size_t char_hex_encode(char *dest, size_t dest_len, const char *src, size_t len)
 	int i, n = dest_len / 2 >= len ? len : dest_len / 2;
 
 	for (i = 0; i < n; i++)
-		snprintf(dest + i * 2, 3, "%02x", char_def_alphabet_encode(src[i]));
+		snprintf(dest + i * 2, 3, "%02X", char_def_alphabet_encode(src[i]));
 	return len * 2;
 }
 
@@ -885,7 +897,8 @@ void char_ucs2_decode(unsigned char* dest, const unsigned char* src, int len)
  *
  * Converts a string from ISO/IEC 8859-1 to UCS-2 encoded as ASCII-encoded hexadecimal bytes.
  * This function should convert "ABC" to "004100420043"
- * Used in AT driver for UCS2 encoding commands.
+ * Used only in AT driver for UCS2 encoding commands.
+ * It reads char by char from the input.
  */
 #define UCS2_SIZE	4
 size_t char_ucs2_encode(char *dest, size_t dest_len, const char *src, size_t len)
@@ -895,19 +908,18 @@ size_t char_ucs2_encode(char *dest, size_t dest_len, const char *src, size_t len
 	MBSTATE mbs;
 
 	MBSTATE_ENC_CLEAR(mbs);
-	for (i = 0, o_len = 0; i < len && o_len < dest_len / UCS2_SIZE; o_len++) {
+	for (i = 0, o_len = 0; i < len && o_len < dest_len / UCS2_SIZE; o_len++, i++) {
 		/*
 		 * We read input by convertible chunks. 'length' is length of
 		 * the read chunk.
 		 */
-		length = char_uni_alphabet_encode(src + i, len - i, &wc, &mbs);
+		length = char_uni_alphabet_encode(src + i, 1, &wc, &mbs);
 		/* We stop reading after first unreadable input */
-		if (!length)
+		if (length < 1)
 			return o_len * UCS2_SIZE;
-		i += length;
 		/* We write here 4 chars + NULL termination */
 		/* XXX: We should probably check wchar_t size. */
-		snprintf(dest + (o_len * UCS2_SIZE), UCS2_SIZE + 1, "%04x", wc);
+		snprintf(dest + (o_len * UCS2_SIZE), UCS2_SIZE + 1, "%04X", wc);
 	}
 	return o_len * UCS2_SIZE;
 }
@@ -969,6 +981,9 @@ unsigned int char_unicode_encode(unsigned char* dest, const unsigned char* src,
 			dest[pos++] =  wc & 0xFF;
 			offset++;
 			break;
+		case 0: /* Avoid infinite loop */
+			offset++;
+			break;
 		default:
 			dest[pos++] =  wc >> 8 & 0xFF;
 			dest[pos++] =  wc & 0xFF;
