@@ -1,5 +1,4 @@
 /*
-  $Id: libfunctions.c,v 1.33 2007/07/10 15:37:02 pkot Exp $
 
   G N O K I I
 
@@ -23,14 +22,14 @@
 
   Copyright (C) 1999-2000 Hugh Blemings & Pavel Janík ml.
   Copyright (C) 2001      Chris Kemp
-  Copyrught (C) 2001-2004 Pawel Kot
+  Copyright (C) 2001-2011 Pawel Kot
   Copyright (C) 2002-2003 BORBELY Zoltan
   Copyright (C) 2002      Pavel Machek, Marcin Wiacek
   Copyright (C) 2006      Helge Deller
 
   Goal of this code is to provide a binary compatible layer to access
   libgnokii.so functions from external programs which are not part
-  of this gnokii CVS package.
+  of this gnokii package.
   One of those external programs is e.g. the Mobile Phone import/export
   filter of the KDE Adressbook (kaddressbook).
   Helge Deller - April 2006
@@ -47,27 +46,60 @@
 #include "gnokii.h"
 #include "device.h"
 
+#ifdef ENABLE_NLS
+#  include <locale.h>
+#endif
+
 /* this macro sets the "lasterror" code */
 #define LASTERROR(state,nr)	((state->lasterror = nr)) /* do not delete the double brackets! */
 
+/**
+ * gn_lib_init:
+ *
+ * returns: GN_ERR_NONE on success, an error on failure
+ *
+ * Initializes the library for use by programs.
+ * Call this function before any other in this library.
+ */
+GNOKII_API gn_error gn_lib_init()
+{
+	static bool initialized = false;
+
+	if (initialized == true)
+		return GN_ERR_NONE;
+
+#ifdef ENABLE_NLS
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+#endif
+	initialized = true;
+
+	return GN_ERR_NONE;
+}
+
 GNOKII_API unsigned int gn_lib_version()
 {
 	/* return the library version number at compile time of libgnokii */
 	return LIBGNOKII_VERSION;
 }
 
-GNOKII_API gn_error gn_lib_phoneprofile_load_from_file(const char *configfile, const char *configname, struct gn_statemachine **state)
+static gn_error load_from_file(const char *configfile, const char *configname)
+{
+	if (configfile && *configfile)
+		return gn_cfg_file_read(configfile);
+	else
+		return gn_cfg_read_default();
+}
+
+static gn_error load_from_memory(char **lines)
+{
+	return gn_cfg_memory_read(lines);
+}
+
+static gn_error phoneprofile_load(const char *configname, gn_error error, struct gn_statemachine **state)
 {
-	gn_error error = GN_ERR_NONE;
 	*state = NULL;
 
-	if (!gn_cfg_info) {
-		if (configfile && *configfile)
-			error = gn_cfg_file_read(configfile);
-		else
-			error = gn_cfg_read_default();
-	}
-	if (GN_ERR_NONE == error) {
+	if (error == GN_ERR_NONE) {
 		/* allocate and initialize data structures */
 		*state = malloc(sizeof(**state));
 		if (*state) {
@@ -79,7 +111,7 @@ GNOKII_API gn_error gn_lib_phoneprofile_load_from_file(const char *configfile, c
 			error = GN_ERR_MEMORYFULL;
 		}
 	}
-	if (GN_ERR_NONE != error) {
+	if (error != GN_ERR_NONE) {
 		gn_lib_phoneprofile_free(state);
 		gn_lib_library_free();
 		return error;
@@ -87,12 +119,31 @@ GNOKII_API gn_error gn_lib_phoneprofile_load_from_file(const char *configfile, c
 	return LASTERROR((*state), GN_ERR_NONE);
 }
 
+GNOKII_API gn_error gn_lib_phoneprofile_load_from_file(const char *configfile, const char *configname, struct gn_statemachine **state)
+{
+	gn_error error = GN_ERR_NONE;
+
+	if (!gn_cfg_info)
+		error = load_from_file(configfile, configname);
+
+	return phoneprofile_load(configname, error, state);
+}
+
+GNOKII_API gn_error gn_lib_phoneprofile_load_from_external(char **lines, struct gn_statemachine **state)
+{
+	gn_error error = GN_ERR_NONE;
+
+	if (!gn_cfg_info)
+		error = load_from_memory(lines);
+
+	return phoneprofile_load(NULL, error, state);
+}
+
 GNOKII_API gn_error gn_lib_phoneprofile_load(const char *configname, struct gn_statemachine **state)
 {
 	return gn_lib_phoneprofile_load_from_file(NULL, configname, state);
 }
 
-
 GNOKII_API gn_error gn_lib_phoneprofile_free( struct gn_statemachine **state )
 {
 	/* free data structure */
@@ -129,7 +180,7 @@ GNOKII_API gn_error gn_lib_phone_open( struct gn_statemachine *state )
 		state->lockfile = gn_device_lock(state->config.port_device);
 		if (state->lockfile == NULL) {
 			fprintf(stderr, _("Lock file error. Exiting.\n"));
-			return LASTERROR(state, GN_ERR_BUSY);
+			return LASTERROR(state, GN_ERR_LOCKED);
 		}
 	}
 
@@ -138,9 +189,11 @@ GNOKII_API gn_error gn_lib_phone_open( struct gn_statemachine *state )
 	if (error != GN_ERR_NONE) {
 		fprintf(stderr, _("Telephone interface init failed: %s\nQuitting.\n"),
 			gn_error_print(error));
-		/* gn_device_unlock frees state->lockfile */
+
+		/* gn_device_unlock() removes lockfile if it was created and frees state->lockfile */
 		gn_device_unlock(state->lockfile);
 		state->lockfile = NULL;
+
 		return LASTERROR(state, error);
 	}
 
@@ -152,11 +205,8 @@ GNOKII_API gn_error gn_lib_phone_close( struct gn_statemachine *state )
 	/* close phone connection */
 	gn_sm_functions(GN_OP_Terminate, NULL, state);
 
-	/* remove lockfile if it was created */
-	if (state->lockfile) {
-		/* gn_device_unlock frees state->lockfile */
-		gn_device_unlock(state->lockfile);
-	}
+	/* gn_device_unlock() removes lockfile if it was created and frees state->lockfile */
+	gn_device_unlock(state->lockfile);
 	state->lockfile = NULL;
 
 	return LASTERROR(state, GN_ERR_NONE);
@@ -181,13 +231,13 @@ static gn_error gn_lib_get_phone_information( struct gn_statemachine *state )
 	error = gn_sm_functions(GN_OP_Identify, data, state);
 
 	if (!data->model[0])
-		strcpy(data->model,        unknown);
+		snprintf(data->model, GN_MODEL_MAX_LENGTH, "%s", unknown);
 	if (!data->manufacturer[0])
-		strcpy(data->manufacturer, unknown);
+		snprintf(data->manufacturer, GN_MANUFACTURER_MAX_LENGTH, "%s", unknown);
 	if (!data->revision[0])
-		strcpy(data->revision,     unknown);
+		snprintf(data->revision, GN_REVISION_MAX_LENGTH, "%s", unknown);
 	if (!data->imei[0])
-		strcpy(data->imei,         unknown);
+		snprintf(data->imei, GN_IMEI_MAX_LENGTH, "%s", unknown);
 
 	return LASTERROR(state, error);
 }
@@ -370,15 +420,15 @@ GNOKII_API gn_error gn_lib_phonebook_write_entry( struct gn_statemachine *state,
 	return LASTERROR(state, error);
 }
 
-GNOKII_API gn_error gn_lib_set_pb_name( struct gn_statemachine *state, const char *name )
+GNOKII_API gn_error gn_lib_set_pb_name(struct gn_statemachine *state, const char *name)
 {
-	strncpy(state->u.pb_entry.name, name, sizeof(state->u.pb_entry.name)-1);
+	snprintf(state->u.pb_entry.name, sizeof(state->u.pb_entry.name), "%s", name);
 	return LASTERROR(state, GN_ERR_NONE);
 }
 
-GNOKII_API gn_error gn_lib_set_pb_number( struct gn_statemachine *state, const char *number )
+GNOKII_API gn_error gn_lib_set_pb_number(struct gn_statemachine *state, const char *number)
 {
-	strncpy(state->u.pb_entry.number, number, sizeof(state->u.pb_entry.number)-1);
+	snprintf(state->u.pb_entry.number, sizeof(state->u.pb_entry.number), "%s", number);
 	return LASTERROR(state, GN_ERR_NONE);
 }
 
@@ -406,8 +456,8 @@ GNOKII_API gn_error gn_lib_set_pb_date( struct gn_statemachine *state, gn_timest
 	return LASTERROR(state, GN_ERR_NONE);
 }
 
-GNOKII_API gn_error gn_lib_set_pb_subentry( struct gn_statemachine *state, const int index, /* index=-1 appends it */
-        gn_phonebook_entry_type entry_type, gn_phonebook_number_type number_type, const char *number )
+GNOKII_API gn_error gn_lib_set_pb_subentry(struct gn_statemachine *state, const int index, /* index=-1 appends it */
+        gn_phonebook_entry_type entry_type, gn_phonebook_number_type number_type, const char *number)
 {
 	int i = (index==-1) ? gn_lib_get_pb_num_subentries(state) : index;
 	if (i<0 || i>=GN_PHONEBOOK_SUBENTRIES_MAX_NUMBER)
@@ -418,7 +468,7 @@ GNOKII_API gn_error gn_lib_set_pb_subentry( struct gn_statemachine *state, const
 
 	state->u.pb_entry.subentries[i].entry_type  = entry_type;
 	state->u.pb_entry.subentries[i].number_type = number_type;
-	strncpy(state->u.pb_entry.subentries[i].data.number, number, sizeof(state->u.pb_entry.subentries[i].data.number)-1);
+	snprintf(state->u.pb_entry.subentries[i].data.number, sizeof(state->u.pb_entry.subentries[i].data.number), "%s", number);
 	return LASTERROR(state, GN_ERR_NONE);
 }
 
@@ -466,13 +516,20 @@ static struct { gn_connection_type ct; const char *str; } connectiontypes[] = {
 #ifdef HAVE_LIBUSB
 	{ GN_CT_DKU2LIBUSB, "dku2libusb" },
 #endif
+#ifdef HAVE_PCSC
+	{ GN_CT_PCSC,       "libpcsclite" },
+	{ GN_CT_PCSC,       "pcsc" },
+#endif
 #ifndef WIN32
 	{ GN_CT_TCP,        "tcp" },
 #endif
-	{ GN_CT_Tekram,     "tekram" }
+	{ GN_CT_Tekram,     "tekram" },
+#ifdef HAVE_SOCKETPHONET
+	{ GN_CT_SOCKETPHONET, "phonet" },
+#endif
 };
 
-gn_connection_type gn_get_connectiontype(const char *connection_type_string)
+GNOKII_API gn_connection_type gn_get_connectiontype(const char *connection_type_string)
 { 
 	int i;
 	for (i = 0; i < sizeof(connectiontypes)/sizeof(connectiontypes[0]); i++)
@@ -488,6 +545,15 @@ GNOKII_API const char *gn_lib_get_supported_connection(const int num)
 	return connectiontypes[num].str;
 }
 
+GNOKII_API const char *gn_lib_get_connection_name(gn_connection_type ct)
+{
+	int i;
+	for (i = 0; i < sizeof(connectiontypes)/sizeof(connectiontypes[0]); i++)
+		if (ct == connectiontypes[i].ct)
+			return connectiontypes[i].str;
+	return NULL;
+}
+
 GNOKII_API int gn_lib_is_connectiontype_supported(gn_connection_type ct)
 {
 	switch (ct) {
@@ -517,12 +583,24 @@ GNOKII_API int gn_lib_is_connectiontype_supported(gn_connection_type ct)
 		return 1;
 #else
 		return 0;
+#endif
+	case GN_CT_PCSC:
+#ifdef HAVE_PCSC
+		return 1;
+#else
+		return 0;
 #endif
 	case GN_CT_TCP:
 #ifndef WIN32
 		return 0;
 #else
 		return 1;
+#endif
+	case GN_CT_SOCKETPHONET:
+#ifndef HAVE_SOCKETPHONET
+		return 0;
+#else
+		return 1;
 #endif
 	default:
 		return 0;
@@ -539,6 +617,7 @@ GNOKII_API gn_error gn_lib_search_one_connected_phone(struct gn_statemachine **s
 
 	/* not yet implemented */
 	free(*state);
-	return LASTERROR((*state), GN_ERR_UNKNOWNMODEL);
+	*state = NULL;
+	return GN_ERR_NOTIMPLEMENTED;
 }
 
