@@ -1,10 +1,10 @@
 /*
 
-  $Id: fbus-3110.c,v 1.33 2004/04/29 22:13:12 pkot Exp $
+  $Id$
 
   G N O K I I
 
-  A Linux/Unix toolset and driver for Nokia mobile phones.
+  A Linux/Unix toolset and driver for the mobile phones.
 
   This file is part of gnokii.
 
@@ -22,7 +22,11 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 2000 Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 1999-2000 Hugh Blemings & Pavel Janik ml.
+  Copyright (C) 2001-2004 Pawel Kot
+  Copyright (C) 2002      Ladis Michl
+  Copyright (C) 2002-2003 BORBELY Zoltan
+  Copyright (C) 2003-2004 Osma Suominen
 
   This file provides an API for accessing functions via fbus.
   See README for more details on supported mobile phones.
@@ -31,6 +35,8 @@
 
 */
 
+#include "config.h"
+
 /* System header files */
 
 #include <stdio.h>
@@ -39,13 +45,13 @@
 
 /* Various header file */
 
-#include "config.h"
 #include "compat.h"
 #include "misc.h"
 #include "gnokii-internal.h"
 #include "device.h"
 
 #include "links/fbus-3110.h"
+#include "links/utils.h"
 
 static bool fb3110_serial_open(struct gn_statemachine *state);
 static void fb3110_rx_frame_handle(fb3110_incoming_frame *i, struct gn_statemachine *state);
@@ -58,7 +64,7 @@ static int fb3110_message_type_fold(int type);
 
 /* FIXME - win32 stuff! */
 
-#define FBUSINST(s) ((fb3110_link *)((s)->link.link_instance))
+#define FBUSINST(s) (*((fb3110_link **)(&(s)->link.link_instance)))
 
 
 /*--------------------------------------------*/
@@ -217,12 +223,12 @@ static void fb3110_rx_state_machine(unsigned char rx_byte, struct gn_statemachin
  */
 static gn_error fb3110_loop(struct timeval *timeout, struct gn_statemachine *state)
 {
-	unsigned char buffer[255];
+	unsigned char buffer[BUFFER_SIZE];
 	int count, res;
 
 	res = device_select(timeout, state);
 	if (res > 0) {
-		res = device_read(buffer, 255, state);
+		res = device_read(buffer, sizeof(buffer), state);
 		for (count = 0; count < res; count++)
 			fb3110_rx_state_machine(buffer[count], state);
 	} else
@@ -324,6 +330,12 @@ static void fb3110_tx_ack_send(u8 messagetype, u8 seqno, struct gn_statemachine
 }
 
 
+static void fb3110_reset(struct gn_statemachine *state)
+{
+	/* Init variables */
+	FBUSINST(state)->i.state = FB3110_RX_Sync;
+}
+
 /* 
  * Initialise variables and start the link
  * newlink is actually part of state - but the link code should not
@@ -345,6 +357,7 @@ gn_error fb3110_initialise(struct gn_statemachine *state)
 	/* Fill in the link functions */
 	state->link.loop = &fb3110_loop;
 	state->link.send_message = &fb3110_message_send;
+	state->link.reset = &fb3110_reset;
 
 	/* Check for a valid init length */
 	if (state->config.init_length == 0)
@@ -376,8 +389,7 @@ gn_error fb3110_initialise(struct gn_statemachine *state)
 		device_write(&init_char, 1, state);
 	}
 
-	/* Init variables */
-	FBUSINST(state)->i.state = FB3110_RX_Sync;
+	fb3110_reset(state);
 
 	return GN_ERR_NONE;
 }
@@ -397,7 +409,7 @@ static void fb3110_sequence_number_update(struct gn_statemachine *state)
 }
 
 /* The 3110 protocol has a tendency to use different message types to
- * indicate succesful and failed actions. These are not handled very well by
+ * indicate successful and failed actions. These are not handled very well by
  * the gnokii internals, so they are "folded" together and dealt with in the
  * 3110 code instead. The logic is that each success/failure message type
  * pair is reported as the type of the message to indicate success.
