@@ -210,7 +210,7 @@ static void phonet_rx_statemachine(unsigned char rx_byte, struct gn_statemachine
 static gn_error phonet_loop(struct timeval *timeout, struct gn_statemachine *state)
 {
 	gn_error	error = GN_ERR_INTERNALERROR;
-	unsigned char	buffer[BUFFER_SIZE];
+	unsigned char	buffer[BUFFER_SIZE + 16];
 	int		count, res;
 
 	res = device_select(timeout, state);
@@ -242,7 +242,9 @@ static gn_error phonet_send_message(unsigned int messagesize, unsigned char mess
 	if (!state)
 		return GN_ERR_FAILED;
 
-	/* FIXME - we should check for the message length ... */
+	if (messagesize > PHONET_TRANSMIT_MAX_LENGTH) {
+		return GN_ERR_MEMORYFULL;
+	}
 
 	/* Now construct the message header. */
 
@@ -323,6 +325,7 @@ gn_error phonet_initialise(struct gn_statemachine *state)
 	case GN_CT_DKU2:
 	case GN_CT_DKU2LIBUSB:
 	case GN_CT_Bluetooth:
+	case GN_CT_SOCKETPHONET:
 		if (phonet_open(state) == true)
 			error = GN_ERR_NONE;
 		break;
