@@ -50,6 +50,7 @@
 
 #include "misc.h"
 #include "gnokii.h"
+#include "gnokii-internal.h"
 
 GNOKII_API gn_log_target gn_log_debug_mask = GN_LOG_T_NONE;
 GNOKII_API gn_log_target gn_log_rlpdebug_mask = GN_LOG_T_NONE;
@@ -93,6 +94,8 @@ static gn_phone_model models[] = {
 	{"1100",  "RH-18",	PM_OLD_DEFAULT },
 	{"1100",  "RH-38",	PM_OLD_DEFAULT },
 	{"1100b", "RH-36",	PM_OLD_DEFAULT },
+	{"1101",  "RH-75",	PM_OLD_DEFAULT }, /* Yet another 1100 variant, untested */
+	{"1110",  "RH-93",	PM_DEFAULT },     /* Series 30, phone supports a very limited command set */
 	{"1209",  "RH-105",	PM_OLD_DEFAULT }, /* Series 30, phone supports a very limited command set */
 	{"1220",  "NKC-1",	PM_OLD_DEFAULT },
 	{"1260",  "NKW-1",	PM_OLD_DEFAULT },
@@ -126,17 +129,19 @@ static gn_phone_model models[] = {
 	{"2285",  "RH-3",	PM_OLD_DEFAULT },
 	{"2300",  "RM-4",	PM_OLD_DEFAULT },
 	{"2300b", "RM-5",	PM_OLD_DEFAULT },
+	{"2330 classic", "RM-512",	PM_DEFAULT_S40_3RD }, /* Series 40 5th Edition FP 1 Lite */
 	{"2600",  "RH-59",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"2630",  "RM-298",	PM_DEFAULT },
 	{"2650",  "RH-53",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
-	{"2760",  "RM-258",	PM_DEFAULT }, /* Series 40 5th Edition */
+	{"2730 classic",  "RM-578",	PM_DEFAULT_S40_3RD }, /* Series 40 5th Edition FP 1 */
+	{"2760",  "RM-258",	PM_DEFAULT_S40_3RD }, /* Series 40 5th Edition */
 	{"3100",  "RH-19",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"3100b", "RH-50",	PM_DEFAULT },
 	{"3105",  "RH-48",	PM_OLD_DEFAULT },
 	{"3108",  "RH-6",	PM_OLD_DEFAULT },
 	{"3110",  "NHE-8",	PM_OLD_DEFAULT | PM_DATA },
 	{"3110",  "0310" ,	PM_OLD_DEFAULT | PM_DATA }, /* NHE-8 */
-	{"3110c", "RM-237",     PM_DEFAULT | PM_SMSFILE | PM_EXTPBK2 | PM_EXTCALENDAR }, /* Nokia 3110 classic */
+	{"3110c", "RM-237",     PM_DEFAULT_S40_3RD }, /* Nokia 3110 classic */
 	{"3120",  "RH-19",	PM_DEFAULT },
 	{"3120b", "RH-50",	PM_DEFAULT },
 	{"3200",  "RH-30",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
@@ -189,7 +194,7 @@ static gn_phone_model models[] = {
 	{"5120",  "NSC-1",	PM_OLD_DEFAULT  },
 	{"5125",  "NSC-1",	PM_OLD_DEFAULT },
 	{"5130",  "NSK-1",	PM_OLD_DEFAULT | PM_NETMONITOR | PM_DATA | PM_AUTHENTICATION },
-	{"5130 XpressMusic",  "RM-495",	PM_DEFAULT },
+	{"5130 XpressMusic",  "RM-495",	PM_DEFAULT_S40_3RD },
 	{"5140",  "NPL-5",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"5140i", "RM-104",	PM_DEFAULT },
 	{"5160",  "NSW-1",	PM_OLD_DEFAULT | PM_NETMONITOR | PM_DATA | PM_AUTHENTICATION },
@@ -198,8 +203,8 @@ static gn_phone_model models[] = {
 	{"5185",  "NSD-1A",	PM_OLD_DEFAULT },
 	{"5190",  "NSB-1",	PM_OLD_DEFAULT | PM_NETMONITOR | PM_DATA | PM_AUTHENTICATION },
 	{"5210",  "NSM-5",	PM_DEFAULT },
-	{"5300 XpressMusic",  "RM-146",	PM_DEFAULT }, /* Series 40 3rd Edition */
-	{"5310 XpressMusic",  "RM-303",	PM_DEFAULT },
+	{"5300 XpressMusic",  "RM-146",	PM_DEFAULT_S40_3RD },
+	{"5310 XpressMusic",  "RM-303",	PM_DEFAULT_S40_3RD },
 	{"5510",  "NPM-5",	PM_OLD_DEFAULT },
 	{"6010",  "NPM-10",	PM_OLD_DEFAULT },
 	{"6010",  "NPM-10X",	PM_OLD_DEFAULT },
@@ -220,6 +225,7 @@ static gn_phone_model models[] = {
 	{"6110",  "NSE-3",	PM_OLD_DEFAULT | PM_NETMONITOR | PM_DATA | PM_AUTHENTICATION },
 	{"6120",  "NSC-3",	PM_OLD_DEFAULT | PM_NETMONITOR | PM_DATA | PM_AUTHENTICATION },
 	{"6130",  "NSK-3",	PM_OLD_DEFAULT | PM_NETMONITOR | PM_DATA | PM_AUTHENTICATION },
+	{"6133",  "RM-126",	PM_DEFAULT_S40_3RD },
 	{"6136",  "RM-199",	PM_DEFAULT | PM_FULLPBK },
 	{"6138",  "NSK-3",	PM_OLD_DEFAULT },
 	{"6150",  "NSM-1",	PM_OLD_DEFAULT | PM_NETMONITOR | PM_DATA | PM_AUTHENTICATION },
@@ -242,8 +248,8 @@ static gn_phone_model models[] = {
 	{"6233",  "RM123_145_-", PM_DEFAULT | PM_NETMONITOR },
 	{"6250",  "NHM-3",	PM_DEFAULT | PM_NETMONITOR },
 	{"6280",  "RH-78",	PM_DEFAULT | PM_NETMONITOR },
-	{"6300",  "RM-217",     PM_DEFAULT | PM_FULLPBK | PM_SMSFILE | PM_EXTPBK2 | PM_EXTCALENDAR },
-	{"6303",  "RM-443",     PM_DEFAULT | PM_FULLPBK | PM_SMSFILE | PM_EXTPBK2 | PM_EXTCALENDAR }, /* Nokia 6303 classic */
+	{"6300",  "RM-217",     PM_DEFAULT_S40_3RD | PM_FULLPBK },
+	{"6303",  "RM-443",     PM_DEFAULT_S40_3RD | PM_FULLPBK }, /* Nokia 6303 classic */
 	{"6310",  "NPE-4",	PM_DEFAULT },
 	{"6310i", "NPL-1",	PM_DEFAULT },
 	{"6340",  "NPM-2",	PM_OLD_DEFAULT },
@@ -252,6 +258,7 @@ static gn_phone_model models[] = {
 	{"6370",  "NHP-2FX",	PM_OLD_DEFAULT },
 	{"6385",  "NHP-2AX",	PM_OLD_DEFAULT },
 	{"6500",  "NHM-7",	PM_DEFAULT | PM_NETMONITOR },
+	{"6500c", "RM-265",	PM_DEFAULT_S40_3RD | PM_FULLPBK }, /* Series 40 5th Edition */
 	{"6510",  "NPM-9",	PM_DEFAULT },
 	{"6560",  "RH-25",	PM_OLD_DEFAULT },
 	{"6585",  "RH-34",	PM_OLD_DEFAULT },
@@ -262,7 +269,7 @@ static gn_phone_model models[] = {
 	{"6610i", "RM-37",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"6650",  "NHM-1",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"6680",  "RM-36",	PM_DEFAULT | PM_NETMONITOR },
-	{"6700 classic",  "RM-470",	PM_DEFAULT },  /* Series 40 6th Edition */
+	{"6700 classic",  "RM-470",	PM_DEFAULT_S40_3RD },  /* Series 40 6th Edition */
 	{"6800",  "NHL-6",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"6800",  "NSB-9",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"6810",  "RM-2",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
@@ -359,7 +366,7 @@ GNOKII_API gn_phone_model *gn_phone_model_get(const char *product_name)
 
 GNOKII_API const char *gn_model_get(const char *product_name)
 {
-	return (gn_phone_model_get(product_name)->model);
+	return gn_cfg_get_phone_model(gn_cfg_info, product_name)->model;
 }
 
 static void log_printf(gn_log_target mask, const char *fmt, va_list ap)
@@ -629,6 +636,35 @@ void gnokii_strfreev(char **str_array)
 	free(str_array);
 }
 
+/**
+ * gnokii_strcmpsep:
+ * @s1: a string, NUL terminated, may NOT contain @sep
+ * @s2: a string, NUL terminated, may contain @sep
+ * @sep: comparison stops if this char is found in @s2
+ *
+ * Returns: < 0 if @s1 < @s2
+ *            0 if @s1 == @s2
+ *          > 0 if @s1 > @s2
+ *
+ * Compares two strings up to a NUL terminator or a separator char.
+ * Leading and trailing white space in @s2 is ignored.
+ */
+int gnokii_strcmpsep(const char *s1, const char *s2, char sep)
+{
+	while (isblank(*s2))
+		s2++;
+	while (*s1 && *s1 == *s2) {
+		s1++;
+		s2++;
+	}
+	while (isblank(*s2))
+		s2++;
+	if (!*s1 && *s2 == sep)
+		return 0;
+
+	return *s1 - *s2;
+}
+
 /*
  * check if the timestamp in dt has valid date and time
  */
