@@ -323,12 +323,13 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 		if (gn_sm_functions(GN_OP_GetSMSCenter, data, state) == GN_ERR_NONE) {
 			snprintf(sms.smsc.number, sizeof(sms.smsc.number), "%s", data->message_center->smsc.number);
 			sms.smsc.type = data->message_center->smsc.type;
-		} else {
-			fprintf(stderr, _("Cannot read the SMSC number from your phone. If the sms send will fail, please use --smsc option explicitely giving the number.\n"));
 		}
 		free(data->message_center);
 	}
-
+	/* Either GN_OP_GetSMSCenter failed or it succeded and read an empty number */
+	if (!sms.smsc.number[0]) {
+		fprintf(stderr, _("Cannot read the SMSC number from your phone. If the sms send will fail, please use --smsc option explicitely giving the number.\n"));
+	}
 	if (!sms.smsc.type) sms.smsc.type = GN_GSM_NUMBER_Unknown;
 
 	if (curpos != -1) {
@@ -890,7 +891,7 @@ parsefile:
 		default:
 			fprintf(stderr, _("Getting SMS failed (location %d from %s memory)! (%s)\n"), count, memory_type_string, gn_error_print(error));
 			if (error == GN_ERR_INVALIDMEMORYTYPE) {
-				fprintf(stderr, _("Unknown memory type %s (use ME, SM, IN, OU, ...)!\n"), optarg);
+				fprintf(stderr, _("Unknown memory type %s (use ME, SM, IN, OU, ...)!\n"), memory_type_string);
 				fprintf(stderr, _("Run gnokii --showsmsfolderstatus for a list of supported memory types.\n"));
 			}
 			break;
