@@ -1,7 +1,5 @@
 /*
 
-  $Id$
-
   G N O K I I
 
   A Linux/Unix toolset and driver for Nokia mobile phones.
@@ -23,7 +21,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Copyright (C) 1999-2000 Hugh Blemings & Pavel Janik ml.
-  Copyright (C) 2001-2005 Pawel Kot
+  Copyright (C) 2001-2011 Pawel Kot
   Copyright (C) 2001      Chris Kemp
   copyright (C) 2002      Markus Plail
   Copyright (C) 2002-2003 BORBELY Zoltan, Ladis Michl
@@ -64,9 +62,9 @@ typedef unsigned char uint8_t;
 #  endif
 #endif
 
-#define LIBGNOKII_VERSION_STRING "6.0.0"
+#define LIBGNOKII_VERSION_STRING "6.1.0"
 #define LIBGNOKII_VERSION_MAJOR 6
-#define LIBGNOKII_VERSION_MINOR 0
+#define LIBGNOKII_VERSION_MINOR 1
 #define LIBGNOKII_VERSION_RELEASE 0
 #define LIBGNOKII_MAKE_VERSION(a,b,c) (((a) << 16) | ((b) << 8) | (c))
 
@@ -110,6 +108,9 @@ GNOKII_API gn_error gn_lib_lasterror(struct gn_statemachine *state);
    gn_lib_phoneprofile_load assumes default config file. */
 GNOKII_API gn_error gn_lib_phoneprofile_load_from_file(const char *configfile, const char *configname, struct gn_statemachine **state);
 GNOKII_API gn_error gn_lib_phoneprofile_load(const char *configname, struct gn_statemachine **state);
+/* initialize gnokii library and structures for given phone
+   lines is line by line representation as it was read from the config file. */
+GNOKII_API gn_error gn_lib_phoneprofile_load_from_external(char **lines, struct gn_statemachine **state);
 
 /* Free any structures and resources which were loaded in this state machine. */
 GNOKII_API gn_error gn_lib_phoneprofile_free(struct gn_statemachine **state);
