@@ -53,7 +53,8 @@ typedef enum {
 	GN_CT_M2BUS,	/* Serial connection with M2BUS protocol */
 	GN_CT_DKU2,	/* DKU2 usb connection using nokia_dku2 kernel driver */
 	GN_CT_DKU2LIBUSB, /* DKU2 usb connection using libusb */
-	GN_CT_PCSC      /* PC/SC SIM Card reader using libpsclite */
+	GN_CT_PCSC,     /* PC/SC SIM Card reader using libpsclite */
+	GN_CT_SOCKETPHONET /* Linux PHONET kernel driver */
 } gn_connection_type;
 
 GNOKII_API const char *gn_connection_type2str(gn_connection_type t);
@@ -110,7 +111,8 @@ typedef enum {
 	GN_MT_F18,
 	GN_MT_F19,
 	GN_MT_F20, /* 20th CUSTOM FOLDER */
-	GN_MT_LAST = GN_MT_F20,
+	GN_MT_BM, /* Cell Broadcast Messages */
+	GN_MT_LAST = GN_MT_BM,
 	GN_MT_XX = 0xff	/* Error code for unknown memory type (returned by fbus-xxxx functions). */
 } gn_memory_type;
 
@@ -223,19 +225,20 @@ typedef enum {
 	GN_PHONEBOOK_ENTRY_Postal          = 0x09,
 	GN_PHONEBOOK_ENTRY_Note            = 0x0a,
 	GN_PHONEBOOK_ENTRY_Number          = 0x0b,
-	GN_PHONEBOOK_ENTRY_Ringtone        = 0x0c,
+	GN_PHONEBOOK_ENTRY_Ringtone        = 0x0c, /* Ringtone */
 	GN_PHONEBOOK_ENTRY_Date            = 0x13, /* Date is used for DC,RC,etc (last calls) */
 	GN_PHONEBOOK_ENTRY_Pointer         = 0x1a, /* Pointer to the other memory */
-	GN_PHONEBOOK_ENTRY_Logo            = 0x1b,
+	GN_PHONEBOOK_ENTRY_Logo            = 0x1b, /* Bitmap */
 	GN_PHONEBOOK_ENTRY_LogoSwitch      = 0x1c,
-	GN_PHONEBOOK_ENTRY_Group           = 0x1e,
+	GN_PHONEBOOK_ENTRY_Group           = 0x1e, /* Octect */
 	GN_PHONEBOOK_ENTRY_URL             = 0x2c,
-	GN_PHONEBOOK_ENTRY_Location        = 0x2f, /* ??? */
-	GN_PHONEBOOK_ENTRY_Image           = 0x33,
-	GN_PHONEBOOK_ENTRY_RingtoneAdv     = 0x37,
+	GN_PHONEBOOK_ENTRY_Location        = 0x2f, /* Octect */
+	GN_PHONEBOOK_ENTRY_Image           = 0x33, /* File ID */
+	GN_PHONEBOOK_ENTRY_RingtoneAdv     = 0x37, /* File ID or Ringtone */
 	GN_PHONEBOOK_ENTRY_UserID          = 0x38,
-	GN_PHONEBOOK_ENTRY_PTTAddress      = 0x3f, /* string */
+	GN_PHONEBOOK_ENTRY_PTTAddress      = 0x3f,
 	GN_PHONEBOOK_ENTRY_ExtGroup        = 0x43,
+	GN_PHONEBOOK_ENTRY_Video           = 0x45, /* File ID */
 	GN_PHONEBOOK_ENTRY_FirstName       = 0x46,
 	GN_PHONEBOOK_ENTRY_LastName        = 0x47,
 	GN_PHONEBOOK_ENTRY_PostalAddress   = 0x4a,
@@ -249,7 +252,7 @@ typedef enum {
 	GN_PHONEBOOK_ENTRY_JobTitle        = 0x54,
 	GN_PHONEBOOK_ENTRY_Company         = 0x55,
 	GN_PHONEBOOK_ENTRY_Nickname        = 0x56,
-	GN_PHONEBOOK_ENTRY_Birthday        = 0x57,
+	GN_PHONEBOOK_ENTRY_Birthday        = 0x57, /* Date */
 } gn_phonebook_entry_type;
 
 GNOKII_API const char *gn_phonebook_entry_type2str(gn_phonebook_entry_type t);
