@@ -1,10 +1,10 @@
 /*
 
-  $Id: virtmodem.h,v 1.15 2003/03/06 22:32:29 pkot Exp $
+  $Id$
 
   G N O K I I
 
-  A Linux/Unix toolset and driver for Nokia mobile phones.
+  A Linux/Unix toolset and driver for the mobile phones.
 
   This file is part of gnokii.
 
@@ -22,7 +22,9 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999, 2000 Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 1999-2000 Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 2001      Chris Kemp
+  Copyright (C) 2002-2003 Pawel Kot, BORBELY Zoltan
 
   Header file for virtmodem code in virtmodem.c
 
@@ -41,11 +43,11 @@ struct vm_queue {
 extern struct vm_queue queue;
 
 /* Prototypes */
-API int gn_vm_initialise(const char *iname,
-			 char *bindir,
+GNOKII_API int gn_vm_initialise(const char *iname,
+			 const char *bindir,
 			 int debug_mode,
 			 int gn_init);
-API void gn_vm_loop(void);
-API void gn_vm_terminate(void);
+GNOKII_API void gn_vm_loop(void);
+GNOKII_API void gn_vm_terminate(void);
 
 #endif	/* _gnokii_virtmodem_h */
