@@ -1,6 +1,6 @@
 /*
 
-  $Id: nk6100.h,v 1.29 2007/07/07 12:21:21 pkot Exp $
+  $Id$
 
   G N O K I I
 
@@ -22,10 +22,10 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 2000      Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 2000      Hugh Blemings & Pavel Janík ml.
   Copyright (C) 2001-2003 Pawel Kot, BORBELY Zoltan
 
-  This file provides functions specific to the 6100/5100 series.
+  This file provides functions specific to the Nokia 6100/5100 series.
   See README for more details on supported mobile phones.
 
 */
@@ -59,6 +59,7 @@
 #define	NK6100_CAP_NO_PSTATUS	16
 #define	NK6100_CAP_NO_CB	32
 #define	NK6100_CAP_CAL_UNICODE	64
+#define	NK6100_CAP_NO_PB_GROUP	128 /* phone doesn't support categories in phonebook entries (caller groups) */
 
 typedef struct {
 	gn_key_code key;
