@@ -78,41 +78,17 @@ inline static PhoneEvent *RemoveEvent (void)
 
 static gn_error InitModelInf (void)
 {
-  gn_data data;
-  gn_error error;
-  char *aux;
-  char model[GN_MODEL_MAX_LENGTH], rev[GN_REVISION_MAX_LENGTH], 
-	manufacturer[GN_MANUFACTURER_MAX_LENGTH];
+  phoneMonitor.phone.version = gn_lib_get_phone_product_name (sm);
 
-  gn_data_clear(&data);
-  data.manufacturer = manufacturer;
-  data.model = model;
-  data.revision = rev;
-                          
-  error = gn_sm_functions (GN_OP_GetModel, &data, sm);
-  if (error != GN_ERR_NONE)
-  {
-    return error;
-  }
-    
-  g_free (phoneMonitor.phone.version);
-  phoneMonitor.phone.version = g_strdup (model);
+  phoneMonitor.phone.model = gn_lib_get_phone_model (sm);
 
-  g_free (phoneMonitor.phone.model);
-  aux = (char *)gn_phone_model_get(model)->model;
-  if (aux == NULL)
-    phoneMonitor.phone.model = g_strdup (_("unknown"));
-  else
-    phoneMonitor.phone.model = g_strdup (aux);
+  phoneMonitor.supported = gn_phone_model_get (phoneMonitor.phone.model)->flags;
 
-  phoneMonitor.supported = gn_phone_model_get (model)->flags;
+  phoneMonitor.phone.revision = gn_lib_get_phone_revision (sm);
 
-  g_free (phoneMonitor.phone.revision);
-  phoneMonitor.phone.revision = g_strdup (rev);
-
-  gn_log_xdebug ("Version: %s\n", phoneMonitor.phone.version);
-  gn_log_xdebug ("Model: %s\n", phoneMonitor.phone.model);
-  gn_log_xdebug ("Revision: %s\n", phoneMonitor.phone.revision);
+  gn_log_xdebug ("Model        : %s\n", gn_lib_get_phone_model (sm));
+  gn_log_xdebug ("Product name : %s\n", gn_lib_get_phone_product_name (sm));
+  gn_log_xdebug ("Revision     : %s\n", gn_lib_get_phone_revision (sm));
 
   return GN_ERR_NONE;
 }
@@ -134,8 +110,8 @@ static gn_error fbusinit (const char * const iname)
   error = gn_lib_phoneprofile_load(iname, &sm);
   if (error != GN_ERR_NONE)
   {
-    g_print (_("Cannot load phone %s!\nDo you have proper section in gnokiirc?\n"), iname);
-    g_print (_("%s\n"), gn_error_print(error));
+    g_print (_("Cannot load phone %s!\nDo you have proper section in the config file?\n"), iname);
+    g_print (_("Error: %s\n"), gn_error_print (error));
     exit (-1);
   }
 
@@ -148,7 +124,7 @@ static gn_error fbusinit (const char * const iname)
   if (error != GN_ERR_NONE)
   {
     g_print (_("GSM/FBUS init failed! (Unknown model?). Quitting.\n"));
-    g_print (_("%s\n"), gn_error_print(error));
+    g_print (_("Error: %s\n"), gn_error_print (error));
     return (error);
   }
 
@@ -164,9 +140,9 @@ static gn_error fbusinit (const char * const iname)
 
 void InitPhoneMonitor (void)
 {
-  phoneMonitor.phone.model = g_strdup (_("unknown"));
-  phoneMonitor.phone.version = g_strdup (_("unknown"));
-  phoneMonitor.phone.revision = g_strdup (_("unknown"));
+  phoneMonitor.phone.model = _("unknown");
+  phoneMonitor.phone.version = _("unknown");
+  phoneMonitor.phone.revision = _("unknown");
   phoneMonitor.supported = 0;
 //  phoneMonitor.working = FALSE;
 //  phoneMonitor.sms.unRead = 0;
@@ -232,13 +208,15 @@ This should not happen.\nSkipping.");
     msg->memory_type = smsdConfig.memoryType;
     msg->number = i++;
     data.sms = msg;
-    gn_log_xdebug ("Reading SMS %d\n", i - 1);
+    gn_log_xdebug ("Reading SMS %d of %d\n", i - 1, number);
     if ((error = gn_sms_get (&data, sm)) == GN_ERR_NONE)
     {
       phoneMonitor.sms.messages = g_slist_append (phoneMonitor.sms.messages, msg);
       phoneMonitor.sms.number++;
-      
-      if (phoneMonitor.sms.number == number)
+
+      gn_log_xdebug ("Message counter: %d\n", phoneMonitor.sms.number);
+
+      if (phoneMonitor.sms.number >= number)
       {
         pthread_cond_signal (&smsCond);
         return;
@@ -250,15 +228,15 @@ This should not happen.\nSkipping.");
      */
     else if (error == GN_ERR_INVALIDLOCATION && i > 1)
     {
-      gn_log_xdebug ("Invalid location\n");
+      gn_log_xdebug ("gn_sms_get returned error %d: %s\n", error, gn_error_print (error));
       g_free (msg);
       pthread_cond_signal (&smsCond);
       break;
     }
     else
     {
+      gn_log_xdebug ("gn_sms_get returned error %d: %s\n", error, gn_error_print (error));
       g_free (msg);
-      gn_log_xdebug ("gn_sms_get returned %d\n", error);
     }
 
     usleep (500000);
@@ -270,6 +248,7 @@ static gint A_SendSMSMessage (gpointer data)
 {
   D_SMSMessage *d = (D_SMSMessage *) data;
   gn_data *dt;
+  gn_error status;
 
   if (!d)
     return (GN_ERR_UNKNOWN);
@@ -294,12 +273,13 @@ static gint A_SendSMSMessage (gpointer data)
   gn_data_clear (dt);
   dt->sms = d->sms;
   d->status = gn_sms_send (dt, sm);
+  status = d->status;
   free (dt->sms->reference);
   free (dt);
   pthread_cond_signal (&sendSMSCond);
   pthread_mutex_unlock (&sendSMSMutex);
 
-  return (d->status);
+  return (status);
 }
 
 /*
@@ -329,8 +309,8 @@ static gint A_DeleteSMSMessage (gpointer data)
     gn_log_xdebug ("Deleting SMS %d\n", dt->sms->number);
     /* FIXME: error handling */
     error = gn_sms_delete (dt, sm);
+    gn_log_xdebug ("gn_sms_delete returned error %d: %s\n", error, gn_error_print (error));
 
-    gn_log_xdebug ("Error: %s\n", gn_error_print(error));
 //    pthread_mutex_lock (&smsMutex);
     phoneMonitor.sms.messages = g_slist_remove (phoneMonitor.sms.messages, data);
     phoneMonitor.sms.number--;
@@ -407,7 +387,7 @@ static void RealConnect (void *phone)
       SMSFolder.folder_id = smsdConfig.memoryType;
       if ((error = gn_sm_functions (GN_OP_GetSMSFolderStatus, data, sm)) == GN_ERR_NONE)
       {
-        gn_log_xdebug ("GN_OP_GetSMSFolderStatus returned  %d\n",
+        gn_log_xdebug ("GN_OP_GetSMSFolderStatus returned (number) %d\n",
                        SMSFolder.number);
         gn_log_xdebug ("phoneMonitor.sms.number %d\n",
                        phoneMonitor.sms.number);
@@ -429,7 +409,8 @@ static void RealConnect (void *phone)
       {
         gn_log_xdebug ("GN_OP_GetSMSStatus returned (number, unread) %d, %d\n",
                        SMSStatus.number, SMSStatus.unread);
-        gn_log_xdebug ("phoneMonitor %d\n", phoneMonitor.sms.number);
+        gn_log_xdebug ("phoneMonitor.sms.number %d\n",
+                       phoneMonitor.sms.number);
         if (/* phoneMonitor.sms.unRead != SMSStatus.unread || */
             phoneMonitor.sms.number != SMSStatus.number)
         {
