@@ -6,7 +6,7 @@ CREATE TABLE inbox (
   id int(10) unsigned NOT NULL auto_increment,
   number varchar(20) NOT NULL default '',
   smsdate datetime NOT NULL default '0000-00-00 00:00:00',
-  insertdate timestamp(14) NOT NULL,
+  insertdate timestamp DEFAULT CURRENT_TIMESTAMP,
   text text,
   phone tinyint(4),
   processed tinyint(4) NOT NULL default '0',
@@ -16,8 +16,8 @@ CREATE TABLE inbox (
 CREATE TABLE outbox (
   id int(10) unsigned NOT NULL auto_increment,
   number varchar(20) NOT NULL default '',
-  processed_date timestamp(14) NOT NULL,
-  insertdate timestamp(14) NOT NULL,
+  processed_date timestamp DEFAULT 0,
+  insertdate timestamp DEFAULT CURRENT_TIMESTAMP,
   text varchar(160) default NULL,
   phone tinyint(4),
   processed tinyint(4) NOT NULL default '0',
@@ -32,7 +32,7 @@ CREATE TABLE multipartinbox (
   id int(10) unsigned NOT NULL auto_increment,
   number varchar(20) NOT NULL default '',
   smsdate datetime NOT NULL default '0000-00-00 00:00:00',
-  insertdate timestamp(14) NOT NULL,
+  insertdate timestamp DEFAULT CURRENT_TIMESTAMP,
   text text,
   phone tinyint(4),
   processed tinyint(4) NOT NULL default '0',
