@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_dtmf.c,v 1.17 2007/05/30 21:49:39 dforsi Exp $
+  $Id$
 
   X G N O K I I
 
@@ -22,11 +22,13 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999 Pavel Janik ml., Hugh Blemings
   & 1999-2005 Jan Derfinak.
 
 */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <gtk/gtk.h>
 #include "misc.h"
@@ -45,14 +47,6 @@ static ErrorDialog errorDialog = { NULL, NULL };
 static gchar *saveFileName;
 
 
-static inline void Help1(GtkWidget * w, gpointer data)
-{
-	gchar *indx = g_strdup_printf("/help/%s/windows/dtmf/index.html", xgnokiiConfig.help_locale);
-	Help(w, indx);
-	g_free(indx);
-}
-
-
 static inline void ButtonCB(GtkWidget * widget, gpointer data)
 {
 	gchar buf[2] = " ";
@@ -102,8 +96,14 @@ static void OkLoadDialog(GtkWidget * w, GtkFileSelection * fs)
 		return;
 	}
 
-	fgets(line, MAX_DTMF_LENGTH + 1, f);
-	gtk_entry_set_text(GTK_ENTRY(displayEntry), line);
+	if (fgets(line, MAX_DTMF_LENGTH + 1, f) == NULL) {
+		g_snprintf(buf, 80, _("Error reading file!"));
+		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
+		gtk_widget_show(errorDialog.dialog);
+	} else {
+		gtk_entry_set_text(GTK_ENTRY(displayEntry), line);
+	}
+
 	fclose(f);
 }
 
@@ -210,7 +210,6 @@ static GtkItemFactoryEntry menu_items[] = {
 	{NULL, NULL, NULL, 0, "<Separator>"},
 	{NULL, "<control>W", CloseDTMF, 0, NULL},
 	{NULL, NULL, NULL, 0, "<LastBranch>"},
-	{NULL, NULL, Help1, 0, NULL},
 	{NULL, NULL, GUI_ShowAbout, 0, NULL},
 };
 
@@ -223,8 +222,7 @@ static void InitMainMenu(void)
 	menu_items[3].path = _("/File/Sep1");
 	menu_items[4].path = _("/File/_Close");
 	menu_items[5].path = _("/_Help");
-	menu_items[6].path = _("/Help/_Help");
-	menu_items[7].path = _("/Help/_About");
+	menu_items[6].path = _("/Help/_About");
 }
 
 
