@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_logos.c,v 1.46 2007/06/02 10:39:44 dforsi Exp $
+  $Id$
    
   X G N O K I I
 
@@ -22,7 +22,7 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999      Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999      Pavel Janik ml., Hugh Blemings
   Copyright (C) 1999-2005 Jan Derfinak
   Copyright (C) 2000-2001 Marcin Wiacek, Chris Kemp
   Copyright (C) 2002-2006 Pawel Kot
@@ -30,6 +30,8 @@
 
 */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
@@ -991,7 +993,7 @@ void GetLogoEvent(GtkWidget * widget)
 
 	/* prepare data for event */
 	sscanf(netcou, "%s (%[^)])", network, country);
-	strncpy(bitmap.netcode, gn_network_code_find(network, country), 7);
+	strncpy(bitmap.netcode, gn_network_code_find(network, country), sizeof(bitmap.netcode));
 	data->bitmap = &bitmap;
 	e->event = Event_GetBitmap;
 	e->data = data;
@@ -1033,7 +1035,7 @@ void SetLogoEvent(GtkWidget * widget)
 
 	/* prepare data */
 	sscanf(netcou, "%s (%[^)])", network, country);
-	strncpy(bitmap.netcode, gn_network_code_find(network, country), 7);
+	strncpy(bitmap.netcode, gn_network_code_find(network, country), sizeof(bitmap.netcode));
 
 	if (bitmap.type == GN_BMP_CallerLogo) {
 		/* above condition must be there, because if you launch logos before
@@ -1313,7 +1315,7 @@ void ExportLogoFileMain(gchar * name)
 
 	tbitmap = bitmap;
 
-	strncpy(tbitmap.netcode, gn_network_code_get(networkInfo.network_code), 7);
+	strncpy(tbitmap.netcode, gn_network_code_get(networkInfo.network_code), sizeof(tbitmap.netcode));
 
 	error = gn_file_bitmap_save(name, &tbitmap, &statemachine->driver.phone);
 	if (error != GN_ERR_NONE) {
