@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_netmon.c,v 1.18 2007/05/30 21:49:40 dforsi Exp $
+  $Id$
 
   X G N O K I I
 
@@ -22,12 +22,14 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999 Pavel Janik ml., Hugh Blemings
   & 1999-2005 Jan Derfinak.
   Copyright (C) 2002-2004 Pawel Kot
 
 */
 
+#include "config.h"
+
 #ifndef WIN32
 #  include <unistd.h>
 #endif
@@ -48,14 +50,6 @@ static GtkWidget *tableLabels[4][7];
 static GtkWidget *tableProgress[7];
 
 
-static inline void Help1(GtkWidget * w, gpointer data)
-{
-	gchar *indx = g_strdup_printf("/help/%s/windows/netmon/index.html", xgnokiiConfig.help_locale);
-	Help(w, indx);
-	g_free(indx);
-}
-
-
 static inline void CloseNetmon(GtkWidget * w, gpointer data)
 {
 	PhoneEvent *e;
@@ -255,7 +249,6 @@ static GtkItemFactoryEntry menu_items[] = {
 	{NULL, NULL, NetmonOnOff, 1, NULL},
 	{NULL, NULL, NetmonOnOff, 0, NULL},
 	{NULL, NULL, NULL, 0, "<LastBranch>"},
-	{NULL, NULL, Help1, 0, NULL},
 	{NULL, NULL, GUI_ShowAbout, 0, NULL},
 };
 
@@ -268,8 +261,7 @@ static void InitMainMenu(void)
 	menu_items[3].path = _("/Tools/Net monitor o_n");
 	menu_items[4].path = _("/Tools/Net monitor o_ff");
 	menu_items[5].path = _("/_Help");
-	menu_items[6].path = _("/Help/_Help");
-	menu_items[7].path = _("/Help/_About");
+	menu_items[6].path = _("/Help/_About");
 }
 
 
