@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_speed.c,v 1.24 2007/05/31 12:09:47 dforsi Exp $
+  $Id$
 
   X G N O K I I
 
@@ -22,13 +22,14 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999 Pavel Janik ml., Hugh Blemings
   & 1999-2005 Jan Derfinak
   Copyright (C) 2002-2003 Pawel Kot
   Copyright (C) 2002      BORBELY Zoltan, Markus Plail
 
 */
 
+#include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -57,15 +58,6 @@ static gint selectedKey;
 static bool speedDialInitialized;
 
 
-static inline void Help1(GtkWidget * w, gpointer data)
-{
-	gchar *indx =
-	    g_strdup_printf("/help/%s/windows/speeddial/index.html", xgnokiiConfig.help_locale);
-	Help(w, indx);
-	g_free(indx);
-}
-
-
 static void CloseSpeedDial(GtkWidget * w, gpointer data)
 {
 	gtk_widget_hide(GUI_SpeedDialWindow);
@@ -257,7 +249,7 @@ static void SaveSpeedDial(void)
 	if (speedDialInitialized) {
 		for (i = 1; i < 10; i++) {
 			if ((d = (D_SpeedDial *) gtk_clist_get_row_data(GTK_CLIST(clist), i - 1))) {
-				dprintf("locaction: %i\n", d->entry.location);
+				gn_log_xdebug("location: %i\n", d->entry.location);
 				if (d->entry.location == 0)
 					continue;
 				if ((e = (PhoneEvent *) g_malloc(sizeof(PhoneEvent))) == NULL) {
@@ -430,7 +422,7 @@ static void ExportSpeedDialMain(gchar * name)
 
 	for (i = 1; i < 10; i++) {
 		if ((d = (D_SpeedDial *) gtk_clist_get_row_data(GTK_CLIST(clist), i - 1))) {
-			sprintf(buf, "%d;%d;%d;", d->entry.number, d->entry.memory_type,
+			snprintf(buf, sizeof(buf), "%d;%d;%d;", d->entry.number, d->entry.memory_type,
 				d->entry.location);
 			fprintf(f, "%s\n", buf);
 		}
@@ -515,7 +507,6 @@ static GtkItemFactoryEntry menu_items[] = {
 	{NULL, NULL, NULL, 0, "<Branch>"},
 	{NULL, NULL, EditKey, 0, NULL},
 	{NULL, NULL, NULL, 0, "<LastBranch>"},
-	{NULL, NULL, Help1, 0, NULL},
 	{NULL, NULL, GUI_ShowAbout, 0, NULL},
 };
 
@@ -533,8 +524,7 @@ static void InitMainMenu(void)
 	menu_items[8].path = _("/_Edit");
 	menu_items[9].path = _("/Edit/_Edit");
 	menu_items[10].path = _("/_Help");
-	menu_items[11].path = _("/Help/_Help");
-	menu_items[12].path = _("/Help/_About");
+	menu_items[11].path = _("/Help/_About");
 }
 
 
